@@ -24,7 +24,7 @@ def language_detection():
     "--text",
     type=click.STRING,
     required=True,
-    help="text to be detected",
+    help="text to be processed",
 )
 @click.option(
     "-l", "--log-level", type=click.Choice(["INFO", "DEBUG", "ERROR"]), default="INFO"
